
:orphan:

VarDict
=======

Automatically generated index page for VarDict:

.. raw:: html

   <ul>

   </ul>
     <a href="vardict_germline.html">
       <p style="margin-bottom: 5px"><b>VarDict (Germline)</b> <span style="margin-left: 10px; color: darkgray">vardict_germline</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(5 versions)</span><a class="version-button" href="vardict_germline.html" style="margin-bottom: 10px">
       v<b>1.7.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="vardict_somatic.html">
       <p style="margin-bottom: 5px"><b>Vardict (Somatic)</b> <span style="margin-left: 10px; color: darkgray">vardict_somatic</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(5 versions)</span><a class="version-button" href="vardict_somatic.html" style="margin-bottom: 10px">
       v<b>1.7.0</b>
     </a></p>
     </a>
     <hr />
         

